/* eslint-disable @typescript-eslint/no-unused-vars */
/*
 * Copyright (c) 2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import { AbstractClient } from "../../../common/abstract_client"
import { ClientConfig } from "../../../common/interface"
import {
  ModifyInstanceResponse,
  CreateTopicResponse,
  ImportSourceClusterTopicsResponse,
  CreateConsumerGroupRequest,
  CreateRoleResponse,
  DescribeRoleListResponse,
  ModifyInstanceRequest,
  DescribeTopicListRequest,
  DescribeInstanceListRequest,
  CreateInstanceResponse,
  DescribeTopicListResponse,
  DeleteInstanceResponse,
  ConsumeGroupItem,
  TopicItem,
  ModifyConsumerGroupRequest,
  DescribeConsumerGroupRequest,
  DescribeConsumerGroupListRequest,
  ModifyRoleResponse,
  SubscriptionData,
  DescribeConsumerGroupResponse,
  CreateInstanceRequest,
  CreateRoleRequest,
  VpcInfo,
  SourceClusterGroupConfig,
  DeleteTopicRequest,
  DeleteConsumerGroupResponse,
  ImportSourceClusterTopicsRequest,
  DescribeTopicResponse,
  Endpoint,
  ImportSourceClusterConsumerGroupsResponse,
  DeleteRoleResponse,
  ModifyRoleRequest,
  IpRule,
  SourceClusterTopicConfig,
  DescribeTopicStatsOpRequest,
  RoleItem,
  CreateTopicRequest,
  TagFilter,
  DescribeConsumerGroupListResponse,
  DeleteRoleRequest,
  DescribeRoleListRequest,
  ModifyConsumerGroupResponse,
  ModifyTopicRequest,
  DescribeInstanceResponse,
  DescribeTopicStatsOpResponse,
  DeleteConsumerGroupRequest,
  DeleteTopicResponse,
  Filter,
  CreateConsumerGroupResponse,
  ImportSourceClusterConsumerGroupsRequest,
  DeleteInstanceRequest,
  DescribeInstanceRequest,
  Tag,
  InstanceItem,
  ModifyTopicResponse,
  DescribeInstanceListResponse,
  DescribeTopicRequest,
} from "./trocket_models"

/**
 * trocket client
 * @class
 */
export class Client extends AbstractClient {
  constructor(clientConfig: ClientConfig) {
    super("trocket.tencentcloudapi.com", "2023-03-08", clientConfig)
  }

  /**
   * 修改主题属性
   */
  async ModifyTopic(
    req: ModifyTopicRequest,
    cb?: (error: string, rep: ModifyTopicResponse) => void
  ): Promise<ModifyTopicResponse> {
    return this.request("ModifyTopic", req, cb)
  }

  /**
   * 添加角色
   */
  async CreateRole(
    req: CreateRoleRequest,
    cb?: (error: string, rep: CreateRoleResponse) => void
  ): Promise<CreateRoleResponse> {
    return this.request("CreateRole", req, cb)
  }

  /**
   * 导入消费者组列表
   */
  async ImportSourceClusterConsumerGroups(
    req: ImportSourceClusterConsumerGroupsRequest,
    cb?: (error: string, rep: ImportSourceClusterConsumerGroupsResponse) => void
  ): Promise<ImportSourceClusterConsumerGroupsResponse> {
    return this.request("ImportSourceClusterConsumerGroups", req, cb)
  }

  /**
   * 删除实例
   */
  async DeleteInstance(
    req: DeleteInstanceRequest,
    cb?: (error: string, rep: DeleteInstanceResponse) => void
  ): Promise<DeleteInstanceResponse> {
    return this.request("DeleteInstance", req, cb)
  }

  /**
   * 创建消费组
   */
  async CreateConsumerGroup(
    req: CreateConsumerGroupRequest,
    cb?: (error: string, rep: CreateConsumerGroupResponse) => void
  ): Promise<CreateConsumerGroupResponse> {
    return this.request("CreateConsumerGroup", req, cb)
  }

  /**
     * 查询角色列表，Filter参数使用说明如下：

1. RoleName，角色名称模糊搜索
     */
  async DescribeRoleList(
    req: DescribeRoleListRequest,
    cb?: (error: string, rep: DescribeRoleListResponse) => void
  ): Promise<DescribeRoleListResponse> {
    return this.request("DescribeRoleList", req, cb)
  }

  /**
   * 运营端查询topicStata
   */
  async DescribeTopicStatsOp(
    req: DescribeTopicStatsOpRequest,
    cb?: (error: string, rep: DescribeTopicStatsOpResponse) => void
  ): Promise<DescribeTopicStatsOpResponse> {
    return this.request("DescribeTopicStatsOp", req, cb)
  }

  /**
   * 删除消费组
   */
  async DeleteConsumerGroup(
    req: DeleteConsumerGroupRequest,
    cb?: (error: string, rep: DeleteConsumerGroupResponse) => void
  ): Promise<DeleteConsumerGroupResponse> {
    return this.request("DeleteConsumerGroup", req, cb)
  }

  /**
   * 修改消费组属性
   */
  async ModifyConsumerGroup(
    req: ModifyConsumerGroupRequest,
    cb?: (error: string, rep: ModifyConsumerGroupResponse) => void
  ): Promise<ModifyConsumerGroupResponse> {
    return this.request("ModifyConsumerGroup", req, cb)
  }

  /**
   * 删除角色
   */
  async DeleteRole(
    req: DeleteRoleRequest,
    cb?: (error: string, rep: DeleteRoleResponse) => void
  ): Promise<DeleteRoleResponse> {
    return this.request("DeleteRole", req, cb)
  }

  /**
   * 查询消费组详情
   */
  async DescribeConsumerGroup(
    req: DescribeConsumerGroupRequest,
    cb?: (error: string, rep: DescribeConsumerGroupResponse) => void
  ): Promise<DescribeConsumerGroupResponse> {
    return this.request("DescribeConsumerGroup", req, cb)
  }

  /**
   * 创建主题
   */
  async CreateTopic(
    req: CreateTopicRequest,
    cb?: (error: string, rep: CreateTopicResponse) => void
  ): Promise<CreateTopicResponse> {
    return this.request("CreateTopic", req, cb)
  }

  /**
   * 购买新实例
   */
  async CreateInstance(
    req: CreateInstanceRequest,
    cb?: (error: string, rep: CreateInstanceResponse) => void
  ): Promise<CreateInstanceResponse> {
    return this.request("CreateInstance", req, cb)
  }

  /**
   * 查询实例信息
   */
  async DescribeInstance(
    req: DescribeInstanceRequest,
    cb?: (error: string, rep: DescribeInstanceResponse) => void
  ): Promise<DescribeInstanceResponse> {
    return this.request("DescribeInstance", req, cb)
  }

  /**
   * 删除主题
   */
  async DeleteTopic(
    req: DeleteTopicRequest,
    cb?: (error: string, rep: DeleteTopicResponse) => void
  ): Promise<DeleteTopicResponse> {
    return this.request("DeleteTopic", req, cb)
  }

  /**
   * 导入topic列表
   */
  async ImportSourceClusterTopics(
    req: ImportSourceClusterTopicsRequest,
    cb?: (error: string, rep: ImportSourceClusterTopicsResponse) => void
  ): Promise<ImportSourceClusterTopicsResponse> {
    return this.request("ImportSourceClusterTopics", req, cb)
  }

  /**
     * 获取实例列表，Filters参数使用说明如下：
1. InstanceName, 名称模糊查询
2. InstanceId，实例ID查询
3. InstanceType, 实例类型查询，支持多选
3. InstanceStatus，实例状态查询，支持多选

当使用TagFilters查询时，Filters参数失效。
     */
  async DescribeInstanceList(
    req: DescribeInstanceListRequest,
    cb?: (error: string, rep: DescribeInstanceListResponse) => void
  ): Promise<DescribeInstanceListResponse> {
    return this.request("DescribeInstanceList", req, cb)
  }

  /**
     * 获取消费组列表，Filter参数使用说明如下：

1. ConsumerGroupName，名称模糊查询
2. ConsumeMessageOrderly，投递顺序性。"true":顺序投递；"false":并发投递
     */
  async DescribeConsumerGroupList(
    req: DescribeConsumerGroupListRequest,
    cb?: (error: string, rep: DescribeConsumerGroupListResponse) => void
  ): Promise<DescribeConsumerGroupListResponse> {
    return this.request("DescribeConsumerGroupList", req, cb)
  }

  /**
   * 修改角色
   */
  async ModifyRole(
    req: ModifyRoleRequest,
    cb?: (error: string, rep: ModifyRoleResponse) => void
  ): Promise<ModifyRoleResponse> {
    return this.request("ModifyRole", req, cb)
  }

  /**
     * 查询主题详情，Offset和Limit参数是指订阅该主题的消费组查询分页参数，Filter参数使用说明如下：

ConsumerGroup，消费组名称过滤
     */
  async DescribeTopic(
    req: DescribeTopicRequest,
    cb?: (error: string, rep: DescribeTopicResponse) => void
  ): Promise<DescribeTopicResponse> {
    return this.request("DescribeTopic", req, cb)
  }

  /**
     * 获取主题列表，Filter参数使用说明如下：

1. TopicName，主题名称模糊搜索
2. TopicType，主题类型查询，支持多选，可选值：Normal,Order,Transaction,DelayScheduled
     */
  async DescribeTopicList(
    req: DescribeTopicListRequest,
    cb?: (error: string, rep: DescribeTopicListResponse) => void
  ): Promise<DescribeTopicListResponse> {
    return this.request("DescribeTopicList", req, cb)
  }

  /**
   * 修改实例属性
   */
  async ModifyInstance(
    req: ModifyInstanceRequest,
    cb?: (error: string, rep: ModifyInstanceResponse) => void
  ): Promise<ModifyInstanceResponse> {
    return this.request("ModifyInstance", req, cb)
  }
}
